#if defined _vip_ammo_included
	#endinput
#endif
#define _vip_ammo_included

// Список поддерживаемого оружия:
// SF_GetItemInfo в https://world-source.ru/sm_lib/scripter_functions.zip

enum VIP_Ammo_HookType
{
	//	Впервые устанавливаются патроны из set_ammo.txt или VIP группы, т.к. игрок только что поднял оружие (обойма + запас > 0), которое в текущем раунде ещё никто не поднимал.
	VIP_Ammo_Hook_OnAmmoChangedFirstTime,
	VIP_Ammo_Hook_OnAmmoChangedFirstTimePost,
	
	//	Игрок поднял оружие (в обойме 2+ патронов), которое в текущем раунде уже поднимали, и оказалось, что в обойме патронов больше, чем положено, поэтому лишние были перемещены в запас.
	VIP_Ammo_Hook_OnAmmoInClipReduced,
	VIP_Ammo_Hook_OnAmmoInClipReducedPost,
	
	//	Перезарядка оружия завершена и патроны перераспределяются в обойме/запасе в соответствии с set_ammo.txt и VIP доступом игрока.
	VIP_Ammo_Hook_OnAmmoChangedAfterWeaponReload,
	VIP_Ammo_Hook_OnAmmoChangedAfterWeaponReloadPost
}

typeset VIP_Ammo_HookCB
{
	/**
	 *	VIP_Ammo_Hook_OnAmmoChangedFirstTime
	 *	VIP_Ammo_Hook_OnAmmoInClipReduced
	 *	VIP_Ammo_Hook_OnAmmoChangedAfterWeaponReload
	 *
	 *	@note				События вызываются, только если для оружия изменены патроны в cfg/vip/modules/ammo/set_ammo.txt,
	 *						или у игрока есть доступ к VIP функциям "ammo1_percent"/"ammo2_percent", которые не запрещены в cfg/vip/modules/ammo/no_vip_ammo.txt.
	 *
	 *	@param client		Игрок (возможно бот), чьи патроны вот-вот будут изменены.
	 *	@param sWeapon		Имя оружия (с weapon_), в котором будут изменены патроны.
	 *	@param iWeapon		Индекс оружия.
	 *	@param ammoClip		Патроны, которые будут установлены в обойму.
	 *	@param ammoReserve	Патроны, которые будут установлены в запас .
	 *
	 *	@return				Plugin_Continue/Plugin_Changed = разрешить . Plugin_Stop = запретить.
	 */
	function Action (int client, const char[] sWeapon, int iWeapon, int &ammoClip, int &ammoReserve);
	
	/**
	 *	VIP_Ammo_Hook_OnAmmoChangedFirstTimePost
	 *	VIP_Ammo_Hook_OnAmmoInClipReducedPost
	 *	VIP_Ammo_Hook_OnAmmoChangedAfterWeaponReloadPost
	 */
	function void (int client, const char[] sWeapon, int iWeapon, int ammoClip, int ammoReserve);
}

native void VIP_Ammo_Hook  (VIP_Ammo_HookType type, VIP_Ammo_HookCB callback);
native void VIP_Ammo_Unhook(VIP_Ammo_HookType type, VIP_Ammo_HookCB callback);

public SharedPlugin __pl_VipAmmoVar = 
{
	name = "VipAmmoLib",		/* Имя библиотеки */
	file = "ws_vip/ammo.smx",
	required = 0				/* Не требуется, т.к. включается с задержкой (позже обычных .smx). */
};

public void __pl_VipAmmoVar_SetNTVOptional()
{
	MarkNativeAsOptional("VIP_Ammo_Hook");
	MarkNativeAsOptional("VIP_Ammo_Unhook");
}

/* 

/////

// https://world-source.ru/vip_modules/ammo.zip
#include <vip_ammo>
static const char g_sVipAmmoLib[] = "VipAmmoLib";
bool g_bVipAmmoLib = false;
public void OnAllPluginsLoaded	() { g_bVipAmmoLib = LibraryExists(g_sVipAmmoLib); }
public void OnLibraryAdded		(const char[] name) { if (!strcmp(name, g_sVipAmmoLib)) { g_bVipAmmoLib = true ; } }
public void OnLibraryRemoved	(const char[] name) { if (!strcmp(name, g_sVipAmmoLib)) { g_bVipAmmoLib = false; } }

/////

*/